@@ -1,8 +1,8 @@
-from tutor import hooks
+from tutor import hooks as tutor_hooks
 from .__about__ import __version__
 from . import cli
 
-hooks.Filters.CLI_COMMANDS.add_items(
+tutor_hooks.Filters.CLI_COMMANDS.add_items(
     [
         cli.shell,
         cli.webui,
